texlive[56587] trunk: doc,sync

commits+karl at tug.org commits+karl at tug.org
Wed Oct 7 23:13:01 CEST 2020


Revision: 56587
          http://tug.org/svn/texlive?view=revision&revision=56587
Author:   karl
Date:     2020-10-07 23:13:01 +0200 (Wed, 07 Oct 2020)
Log Message:
-----------
doc,sync

Modified Paths:
--------------
    trunk/Build/source/texk/tests/TeXLive/TLUtils.pm
    trunk/Build/source/texk/texlive/tl_support/fmtutil.cnf
    trunk/Build/source/utils/xindy/README-clisp
    trunk/Master/texmf-dist/scripts/texlive/NEWS

Modified: trunk/Build/source/texk/tests/TeXLive/TLUtils.pm
===================================================================
--- trunk/Build/source/texk/texlive/tl_support/fmtutil.cnf	2020-10-07 21:01:34 UTC (rev 56586)
+++ trunk/Build/source/texk/texlive/tl_support/fmtutil.cnf	2020-10-07 21:13:01 UTC (rev 56587)
@@ -1,4 +1,4 @@
-# Generated by /home/texlive/karl/Master/bin/x86_64-linux/tlmgr on Thu Apr 16 01:56:35 2020
+# Generated by /home/texlive/karl/Master/bin/x86_64-linux/tlmgr on Sat Oct  3 02:49:47 2020
 # Originally written by Thomas Esser, 1998. Public domain.
 #
 # For guidance on how to support local formats, see the man
@@ -42,7 +42,6 @@
 #
 # from aleph:
 aleph aleph - *aleph.ini
-lamed aleph language.dat *lambda.ini
 #
 # from amstex:
 amstex pdftex - -translate-file=cp227.tcx *amstex.ini

Modified: trunk/Build/source/utils/xindy/README-clisp
===================================================================
--- trunk/Build/source/utils/xindy/README-clisp	2020-10-07 21:01:34 UTC (rev 56586)
+++ trunk/Build/source/utils/xindy/README-clisp	2020-10-07 21:13:01 UTC (rev 56587)
@@ -1,5 +1,6 @@
 (This file public domain.)
 
 GNU clisp (gnu.org/software/clisp) is required by xindy.
-See the end of ../README (that is, Buid/source/utils/README) for
-information on building it.
+
+See the end of ../README (that is, Build/source/utils/README in the
+TeX Live repository) for information on building it.

Modified: trunk/Master/texmf-dist/scripts/texlive/NEWS
===================================================================
--- trunk/Master/texmf-dist/scripts/texlive/NEWS	2020-10-07 21:01:34 UTC (rev 56586)
+++ trunk/Master/texmf-dist/scripts/texlive/NEWS	2020-10-07 21:13:01 UTC (rev 56587)
@@ -1,14 +1,18 @@
 (This file public domain.  Originally written by Norbert Preining and
 Karl Berry, 2010.)
 
-<p><b>tlmgr NNNNN (released 8oct20):</b>
-<li>fix for tlmgr info --data printing incorrect relocatable data.
-<li>tlmgr info: support lcat-* and rcat-* fields.
+<p><b>tlmgr 56566 (released 8oct20):</b>
+<li>avoid tlmgr info --data printing incorrect relocatable data.
+<li>tlmgr restore: ensure depending formats are rebuilt.
 <li>Windows: support batch uninstallation by passing any argument.
-<li>Windows: silence warnings due to failures in broadcast_env.
-<li>tlmgr restore: ensure depending formats are rebuilt.
-<li>tlmgr/TLPaper: fix location of pdftexconfig.tex file.
+<li>Windows: silence spurious warnings due to failures in broadcast_env.
 
+<p><b>tlmgr 56458 (released 30sep20):</b>
+<li>tlmgr info reports new lcat-* and rcat-* fields for local vs. remote data.
+
+<p><b>tlmgr 56372 (released 22sep20):</b>
+<li>small fixes for warnings, csv output, xdvi paper location.
+
 <p><b>tlmgr 55369 (released 1jun20):</b>
 <li>full logging of subcommands moved to new file tlmgr-commands.log.
 
@@ -22,7 +26,7 @@
 
 <p><b>tlmgr 54118 (released 7mar20):</b>
 <li>re-initialize LWP connection after 5 errors.
-<li>more specific verification error messages
+<li>more specific verification error messages.
 
 <p><b>tlmgr 53428 (released 17jan20):</b>
 <li>automatic retry of packages that fail to download.



More information about the tex-live-commits mailing list.
--- trunk/Build/source/texk/tests/TeXLive/TLUtils.pm	2020-10-07 21:01:34 UTC (rev 56586)
+++ trunk/Build/source/texk/tests/TeXLive/TLUtils.pm	2020-10-07 21:13:01 UTC (rev 56587)
@@ -5,7 +5,7 @@
 
 package TeXLive::TLUtils;
 
-my $svnrev = '$Revision: 55178 $';
+my $svnrev = '$Revision: 56565 $';
 my $_modulerevision = ($svnrev =~ m/: ([0-9]+) /) ? $1 : "unknown";
 sub module_revision { return $_modulerevision; }
 
@@ -340,10 +340,9 @@
   
   if ($OS eq "darwin") {
     # We have two versions of Mac binary sets.
     # 10.10/Yosemite and newer (Yosemite specially left over):
     #   -> x86_64-darwin [MacTeX]
     # 10.6/Snow Leopard through 10.10/Yosemite:
     #   -> x86_64-darwinlegacy if 64-bit
     #
     # (BTW, uname -r numbers are larger by 4 than the Mac minor version.
     # We don't use uname numbers here.)
@@ -355,13 +354,16 @@
     # returns "10.x" values), and sysctl (processor hardware).
     chomp (my $sw_vers = `sw_vers -productVersion`);
     my ($os_major,$os_minor) = split (/\./, $sw_vers);
-    if ($os_major != 10) {
+    if ($os_major < 10) {
       warn "$0: only MacOSX is supported, not $OS $os_major.$os_minor "
            . " (from sw_vers -productVersion: $sw_vers)\n";
       return "unknownmac-unknownmac";
     }
-    if ($os_minor >= $mactex_darwin) {
-      ; # current version, default is ok (x86_64-darwin).
+    if ($os_major >= 11) {
+      $CPU = "x86_64";
+      $OS = "darwin";
+    } elsif ($os_minor >= $mactex_darwin) {
+      ; # sufficiently new 10.x, default is ok (x86_64-darwin).
     } elsif ($os_minor >= 6 && $os_minor < $mactex_darwin) {
       # in between, x86 hardware only.  On 10.6 only, must check if 64-bit,
       # since if later than that, always 64-bit.
@@ -4167,6 +4169,7 @@
   $ret{'revision'}  = "revA:revB" # if revisions differ
   $ret{'removed'}   = \[ list of files removed from A to B ]
   $ret{'added'}     = \[ list of files added from A to B ]
+  $ret{'fmttriggers'} = 1 if the fmttriggers have changed
 
 =cut
 
@@ -4197,6 +4200,51 @@
   $ret{'removed'} = \@rem if @rem;
   $ret{'added'} = \@add if @add;
 
+  # changed dependencies should not trigger a change without a
+  # change in revision, so for now (until we find a reason why
+  # we need to) we don't check.
+  # OTOH, execute statements like
+  #   execute AddFormat name=aleph engine=aleph options=*aleph.ini fmttriggers=cm,hyphen-base,knuth-lib,plain
+  # might change due to changes in the fmttriggers variables.
+  # Again, name/engine/options are only defined in the package's
+  # tlpsrc file, so changes here will trigger revision changes,
+  # but fmttriggers are defined outside the tlpsrc and thus do
+  # not trigger an automatic revision change. Check for that!
+  # No need to record actual changes, just record that it has changed.
+  my %triggersA;
+  my %triggersB;
+  # we sort executes after format/engine like fmtutil does, since this
+  # should be unique
+  for my $e ($tlpA->executes) {
+    if ($e =~ m/AddFormat\s+(.*)\s*/) {
+      my %r = parse_AddFormat_line("$1");
+      if (defined($r{"error"})) {
+        die "$r{'error'} when comparing packages $tlpA->name execute $e";
+      }
+      for my $t (@{$r{'fmttriggers'}}) {
+        $triggersA{"$r{'name'}:$r{'engine'}:$t"} = 1;
+      }
+    }
+  }
+  for my $e ($tlpB->executes) {
+    if ($e =~ m/AddFormat\s+(.*)\s*/) {
+      my %r = parse_AddFormat_line("$1");
+      if (defined($r{"error"})) {
+        die "$r{'error'} when comparing packages $tlpB->name execute $e";
+      }
+      for my $t (@{$r{'fmttriggers'}}) {
+        $triggersB{"$r{'name'}:$r{'engine'}:$t"} = 1;
+      }
+    }
+  }
+  for my $t (keys %triggersA) {
+    delete($triggersA{$t});
+    delete($triggersB{$t});
+  }
+  if (keys(%triggersA) || keys(%triggersB)) {
+    $ret{'fmttrigger'} = 1;
+  }
+
   return %ret;
 }
 
@@ -340,10 +340,9 @@
   if ($OS eq "darwin") {
     # We have two versions of Mac binary sets.
-    # 10.10/Yosemite and newer (Yosemite specially left over):
-    #   -> x86_64-darwin [MacTeX]
-    # 10.6/Snow Leopard through 10.10/Yosemite:
-    #   -> x86_64-darwinlegacy if 64-bit
+    # 10.x and newer -> x86_64-darwin [MacTeX]
+    # 10.6/Snow Leopard through 10.x -> x86_64-darwinlegacy, if 64-bit
+    # x changes every year. In 2020 (Big Sur) Apple started with 11.x.
     #
     # (BTW, uname -r numbers are larger by 4 than the Mac minor version.

Modified: trunk/Build/source/texk/texlive/tl_support/fmtutil.cnf
===================================================================